Documentation
¶
Index ¶
- Variables
- func AptGetInstallCmd(tool string)
- func AptGetUpdateCmd()
- func CheckToolExists(tool string) bool
- func Consent(tool string) rune
- func DownloadFileFromURL(url string, filepath string) error
- func DownloadFromGithub(toolFullPath, downloadURL string) error
- func DownloadFromGithubAndInstall(tool string) (string, error)
- func DpkgIsPackageInstalled(pkg string) bool
- func FetchAndDownloadLatestVersionFromGitHub(tool string) (string, string, error)
- func GetDownloadURL(tool string, latest Release) (string, error)
- func InstallBinary(tool, extractedBinaryPath string) (string, error)
- func InstallConda() error
- func InstallGCPIAMBrute() error
- func InstallMissingTools(kind rune, optInstall *bool)
- func OSCPConsent(tool string) rune
- func PrintInstallingTool(tool string)
- func Unzip(src, dest string) (string, error)
- type Asset
- type Host
- type Release
Constants ¶
This section is empty.
Variables ¶
HostOS identifies the current host platform
var Updated bool
Global flag to track if apt-get update has been run
Functions ¶
func AptGetInstallCmd ¶
func AptGetInstallCmd(tool string)
AptGetInstallCmd runs the apt-get install <tool> command
func CheckToolExists ¶
CheckToolExists checks that the tool exists with exec.LookPath (equivalent to `which <tool>`)
func DownloadFileFromURL ¶
DownloadFileFromURL downloads a file from url to the specified filepath.
func DownloadFromGithub ¶
DownloadFromGithub downloads a file from GitHub to toolFullPath.
func DownloadFromGithubAndInstall ¶
DownloadFromGithubAndInstall downloads and installs a tool from GitHub.
func DpkgIsPackageInstalled ¶
func FetchAndDownloadLatestVersionFromGitHub ¶
FetchAndDownloadLatestVersionFromGitHub fetches the latest release from GitHub and downloads the tool.
func GetDownloadURL ¶
GetDownloadURL returns the download URL for the tool matching the host platform.
func InstallBinary ¶
InstallBinary installs a binary to the system PATH.
func InstallGCPIAMBrute ¶
func InstallGCPIAMBrute() error
InstallGCPIAMBrute installs gcp-iam-brute and its role definitions. Uses ~/.local paths when not running as root. If the install directory already exists, only the wrapper is (re)created to avoid hanging on pip/network operations for an already-present installation.
func InstallMissingTools ¶
InstallMissingTools instructs the program to try and install tools that are absent from the pentesting distro. Case 'c' installs key cloud tools Case 'i' installs key infra tools
func OSCPConsent ¶
OSCPConsent asks for user consent to run any forbidden tool for OSCP
func PrintInstallingTool ¶
func PrintInstallingTool(tool string)
Types ¶
type Asset ¶
type Asset struct {
BrowserDownloadURL string `json:"browser_download_url"`
Name string `json:"name"`
}
Asset represents a GitHub release asset